@@ -23,12 +23,13 @@ import subprocess
 import sys
 import urllib.parse
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Literal, NoReturn, cast
+from typing import TYPE_CHECKING, Literal, NoReturn, cast
 
 import packaging.requirements
 import packaging.utils
 
 import nox.command
+import nox.registry
 import nox.virtualenv
 from nox import _options, tasks, workflow
 from nox._options import DefaultStr
@@ -37,6 +38,7 @@ from nox.logger import logger, setup_logging
 from nox.project import load_toml
 
 if TYPE_CHECKING:
+    from argparse import Namespace
     from collections.abc import Generator
 
 __all__ = ["execute_workflow", "main", "nox_main"]
@@ -46,7 +48,7 @@ def __dir__() -> list[str]:
     return __all__
 
 
-def execute_workflow(args: Any) -> int:
+def execute_workflow(args: Namespace) -> int:
     """
     Execute the appropriate tasks.
     """
@@ -270,6 +272,7 @@ def _main(*, main_ep: bool) -> None:
                     download_python=download_python,
                 )
 
+    nox.registry.reset()
     exit_code = execute_workflow(args)
 
     # Done; exit.
