@@ -17,7 +17,6 @@ from __future__ import annotations
 import ast
 import itertools
 import operator
-from collections import OrderedDict
 from typing import TYPE_CHECKING, Any, Mapping, cast
 
 from nox._decorators import Call, Func
@@ -40,7 +39,7 @@ WARN_PYTHONS_IGNORED = "python_ignored"
 
 def _unique_list(*args: str) -> list[str]:
     """Return a list without duplicates, while preserving order."""
-    return list(OrderedDict.fromkeys(args))
+    return list(dict.fromkeys(args))
 
 
 class Manifest:
@@ -265,7 +264,7 @@ class Manifest:
         }
 
         # Resolve the dependency graph.
-        root = cast(SessionRunner, object())  # sentinel
+        root = cast("SessionRunner", object())  # sentinel
         try:
             resolved_graph = list(
                 lazy_stable_topo_sort({**dependency_graph, root: self._queue}, root)
@@ -453,8 +452,8 @@ class KeywordLocals(Mapping[str, bool]):
 def keyword_match(expression: str, keywords: Iterable[str]) -> Any:
     """See if an expression matches the given set of keywords."""
     # TODO: see if we can use ast.literal_eval here.
-    locals = KeywordLocals(set(keywords))
-    return eval(expression, {}, locals)  # noqa: S307
+    my_locals = KeywordLocals(set(keywords))
+    return eval(expression, {}, my_locals)  # noqa: S307
 
 
 def _null_session_func_(session: Session) -> None:
