@@ -26,7 +26,7 @@ if TYPE_CHECKING:
 
     from ._typing import Python
 
-__all__ = ["get", "session_decorator"]
+__all__ = ["get", "reset", "session_decorator"]
 
 
 def __dir__() -> list[str]:
@@ -38,6 +38,10 @@ RawFunc = Callable[..., Any]
 _REGISTRY: dict[str, Func] = {}
 
 
+def reset() -> None:
+    _REGISTRY.clear()
+
+
 @overload
 def session_decorator(func: RawFunc | Func, /) -> Func: ...
 
@@ -98,6 +102,9 @@ def session_decorator(
             download_python=download_python,
         )
 
+    if isinstance(func, Func):
+        func = func.func
+
     if py is not None and python is not None:
         msg = (
             "The py argument to nox.session is an alias for the python "
