@@ -28,7 +28,6 @@ from pathlib import Path
 from socket import gethostbyname
 from typing import TYPE_CHECKING, Any, ClassVar, Literal
 
-import pbs_installer
 from packaging import version
 
 import nox
@@ -195,7 +194,7 @@ def _find_pbs_python(implementation: str, version: str) -> str | None:
 def pbs_install_python(python_version: str) -> str | None:
     """Attempts to install a given python version with pbs-installer.
 
-    Returns the full path to the installed  executable, or None if installation failed.
+    Returns the full path to the installed executable, or None if installation failed.
     """
 
     # separate implementation / xyz version
@@ -217,6 +216,15 @@ def pbs_install_python(python_version: str) -> str | None:
     if python_exe := _find_pbs_python(implementation, xyz_ver):
         return python_exe
 
+    # Requires the [pbs] extra to make it past here
+    try:
+        import pbs_installer  # noqa: PLC0415
+    except ModuleNotFoundError:  # pragma: nocover
+        logger.warning(
+            "Nox was installed without the `[pbs]` extra, can't download Python"
+        )
+        return None
+
     try:
         pbs_installer.install(
             xyz_ver,
@@ -224,7 +232,7 @@ def pbs_install_python(python_version: str) -> str | None:
             version_dir=True,
             implementation=implementation,
         )
-    except Exception as err:
+    except Exception as err:  # noqa: BLE001
         logger.warning(f"Failed to install a pbs version for {python_version=}: {err}")
         return None
 
@@ -436,7 +444,7 @@ class CondaEnv(ProcessEnv):
         venv_params: Sequence[str] = (),
         conda_cmd: str = "conda",
         **kwargs: Any,
-    ):
+    ) -> None:
         self.location_name = location
         self.location = os.path.abspath(location)
         self.interpreter = interpreter
@@ -529,7 +537,7 @@ class CondaEnv(ProcessEnv):
         try:
             # DNS resolution to detect situation (1) or (2).
             host = gethostbyname("repo.anaconda.com")
-        except BaseException:  # pragma: no cover
+        except OSError:  # pragma: no cover
             return True
         return host is None
 
@@ -571,7 +579,7 @@ class VirtualEnv(ProcessEnv):
         reuse_existing: bool = False,
         venv_backend: str = "virtualenv",
         venv_params: Sequence[str] = (),
-    ):
+    ) -> None:
         # "pypy-" -> "pypy"
         if interpreter and interpreter.startswith("pypy-"):
             interpreter = interpreter[:4] + interpreter[5:]
@@ -794,6 +802,8 @@ class VirtualEnv(ProcessEnv):
                 self._resolved_interpreter if self.interpreter else sys.executable,
                 self.location,
             ]
+            if version.Version("0.8") <= UV_VERSION:
+                cmd += ["--clear"]
         else:
             cmd = [self._resolved_interpreter, "-m", "venv", self.location]
         cmd.extend(self.venv_params)
