@@ -22,26 +22,24 @@ def test_get_dependencies() -> None:
         with pytest.raises(ModuleNotFoundError):
             list(
                 nox._cli.get_dependencies(
-                    packaging.requirements.Requirement("nox[tox_to_nox]")
+                    packaging.requirements.Requirement("nox[tox-to-nox]")
                 )
             )
     else:
         deps = nox._cli.get_dependencies(
-            packaging.requirements.Requirement("nox[tox_to_nox]")
+            packaging.requirements.Requirement("nox[tox-to-nox]")
         )
         dep_list = {
             "argcomplete",
             "attrs",
             "colorlog",
             "dependency-groups",
-            "httpx",
+            "humanize",
             "jinja2",
             "nox",
             "packaging",
-            "pbs-installer",
             "tox",
             "virtualenv",
-            "zstandard",
         }
         if sys.version_info < (3, 9):
             dep_list.add("importlib-resources")
